@@ -1,4 +1,5 @@
 import os
+import json
 from tunas2dsdl.general.utils import Util
 
 try:
@@ -12,7 +13,7 @@ except ImportError:
 class Generation:
     LINESEP_NUM = 1
 
-    def __init__(self, dsdl_version, meta_info, def_info, class_info, data_info, working_dir):
+    def __init__(self, dsdl_version, meta_info, def_info, class_info, data_info, working_dir, separate_flag):
         self._working_dir = working_dir
         self._dsdl_version = dsdl_version
         self._meta_info = meta_info
@@ -20,6 +21,7 @@ class Generation:
         self._data_info = data_info
         self._class_info = class_info
         self._yaml_obj = self._prepare_yaml_obj()
+        self.separate_flag = separate_flag
 
     def _prepare_yaml_obj(self):
         default_yaml = YAML()
@@ -101,10 +103,22 @@ class Generation:
 
     def write_samples(self, file_name, import_list=None):
 
-        dst = os.path.join(self._working_dir, file_name + ".yaml")
+        yaml_file = file_name + ".yaml"
+        dst = os.path.join(self._working_dir, yaml_file)
         self.write_dsdl_version(path=dst)
         self.write_import_list(import_list, path=dst)
         self.write_meta(path=dst)
 
-        with open(dst, "a") as fp:
-            self._yaml_obj["samples"].dump(self._data_info.format(), fp)
+        if not self.separate_flag:
+            with open(dst, "a") as fp:
+                self._yaml_obj["samples"].dump(self._data_info.format(), fp)
+        else:
+            sample_file = "samples.json"
+            data_info = self._data_info.format(sample_file)
+            _data = data_info['data']
+            samples = _data.pop("samples")
+            samples = {"samples": samples}
+            with open(dst, "a") as fp:
+                self._yaml_obj["samples"].dump(data_info, fp)
+            with open(dst.replace(yaml_file, sample_file), 'w') as fp:
+                json.dump(samples, fp)
