@@ -137,7 +137,14 @@ class DetectionParse:
                 sample_item["annotations"] = annotations
 
             sample_container.add_item(sample_item, not self.separate_flag)
-        return (object_struct, sample_struct), sample_container
+
+        if len(object_struct.fields):
+            annotation_field = Field("annotations", field_type="list",
+                                     param=object_struct.as_others_param(sample_struct))
+            sample_struct.add_field(annotation_field)  # 添加annotation field
+            return (object_struct, sample_struct), sample_container
+        else:
+            return (sample_struct,), sample_container
 
     def _read_json(self, file, encoding="utf-8"):
         bytes_info = self.file_client.get(file)
